<?php

global $loginbox_text;
$loginbox_text = array (

'username'				=>	'Gebruikersnaam',
'password'				=>	'Wachtwoord',
'login'					=>	'Login!',

// Added in 0.9.6
'rememberme'				=>	'Onthoudt login', 

// Added in 0.9.7
'lostpassword'				=>	'Wachtwoord verloren?',

);
?>
